<template>
    <div class="app-container">
        <div class="filter-container">
            <div style="display: block">
                <div class="basic_search">
                    <span>区域：</span>
                    <el-select v-model="listQuery.filter.province" clearable filterable @change="changeArea('province')">
                        <el-option
                            v-for="item in provinceList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.city" prop="city" clearable filterable @change="changeArea('city')">
                        <el-option
                            v-for="item in cityList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.district" clearable filterable @change="changeArea('district')">
                        <el-option
                            v-for="item in districtList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.street"clearable filterable @change="changeArea('street')" >
                        <el-option
                            v-for="item in streetList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>
                <div class="basic_search">
                    <el-select v-model="listQuery.filter.committee" clearable filterable>
                        <el-option
                            v-for="item in committeeList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.name"
                        >
                        </el-option>
                    </el-select>
                </div>

            </div>
            <div style="display: block;">
                <div class="basic_search" style="padding-top: 10px;">
                    <span>按时间查询：</span>
                    <el-date-picker
                        value-format="yyyy-MM-dd HH:mm:ss"
                        v-model="validTime"
                        type="datetimerange"
                        :default-time="['00:00:00','23:59:59']"
                        :picker-options="pickerOptions"
                        range-separator="-"
                        start-placeholder="开始日期"
                        end-placeholder="结束日期"
                    >
                    </el-date-picker>
                </div>
                <div class="basic_search" style="padding-top: 10px">
                    <span>安全监管分类：</span>
                    <el-select filterable clearable v-model="listQuery.filter.safetysupervision">
                        <el-option
                            v-for="item in safetySuperVisionList"
                            :key="item.id"
                            :label="item.text"
                            :value="item.text"
                        ></el-option>
                    </el-select>
                </div>
            </div>
            <div style="display: block;">
                <div class="basic_search" style="padding-top: 10px">
                    <span>按企业名称：</span>
                    <el-input filterable clearable v-model="listQuery.filter.enterprisename" style="width:200px">
                    </el-input>
                </div>
                <div class="basic_search" style="padding-top: 10px">
                    <span>上级企业名称：</span>
                    <el-input filterable clearable v-model="listQuery.filter.parententerprisename" style="width:200px">
                    </el-input>
                </div>
            </div>
            <div style="display: block;">
                <div class="basic_search" style="padding-top: 10px">
                    <span>按产品名称：</span>
                    <el-input filterable clearable v-model="listQuery.filter.itemname" style="width:200px">
                    </el-input>
                </div>
                <div class="basic_search" style="padding-top: 10px">
                    <span>按流向码：</span>
                    <el-input filterable clearable v-model="listQuery.filter.itemcode" style="width:200px">
                    </el-input>
                </div>
                <div class="basic_search" style="margin-right: 10px">
                    <el-button style="margin-left: 10px;" type="primary" @click="reset()">重置</el-button>
                    <el-button style="margin-left: 10px;" type="primary" icon="el-icon-search" @click="searchProductSearch('查询','')">查询</el-button>
                    <el-button style="margin-left: 10px;" type="primary" icon="el-icon-download" @click="exportToExcel">导出</el-button>
                </div>
            </div>

        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="tableData"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="产品流向码" prop="itemcode" align="center">
                </el-table-column>
                <el-table-column label="产品名称" prop="itemname" align="center">
                </el-table-column>
                <el-table-column label="箱数" prop="boxnum" align="center">
                </el-table-column>
                <el-table-column label="每箱数量(挂、个)" prop="boxnumber" align="center">
                </el-table-column>
                <el-table-column label="销售数量(挂、个)" prop="salenum" align="center">
                </el-table-column>
                <el-table-column label="销售时间" prop="saletime" align="center">
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[20, 50, 100, 200]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
            <br>
        </div>
    </div>
</template>

<script>
import { computePageCount } from "../../utils";
import { getProductListData ,exportProduct} from "../../api/productPurchaseSearch";
import {getCityListData, getProvinceListData , } from "../../api/area";
import {dictionaryAllItems} from "../../api/dictionary";

export default {
    name: "addSelfExam",
    data(){
        return{
            tableKey:'',
            validTime:['',''],
            cityList:[],
            provinceList:[],
            districtList:[],
            streetList:[],
            committeeList:[],
            safetySuperVisionList:[],
            listQuery: {
                pageSize:20,
                pageIndex:1,
                filter: {
                    province: '',
                    city: '',
                    district: '',
                    street: '',
                    committee: '',
                    starttime: '',
                    endtime: '',
                    safetysupervision: '',
                    enterprisename: '',
                    parententerprisename:'',
                    itemname:'',
                    itemcode:'',
                },
            },
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            listLoading:false,
            productPurchaseData:[],
            pickerOptions: {
            shortcuts: [{
              text: '最近一周',
              onClick(picker) {
                const end = new Date();
                const start = new Date();
                start.setTime(start.getTime() - 3600 * 1000 * 24 * 7);
                picker.$emit('pick', [start, end]);
              }
            }, {
              text: '最近一个月',
              onClick(picker) {
                const end = new Date();
                const start = new Date();
                start.setTime(start.getTime() - 3600 * 1000 * 24 * 30);
                picker.$emit('pick', [start, end]);
              }
            }, {
              text: '最近三个月',
              onClick(picker) {
                const end = new Date();
                const start = new Date();
                start.setTime(start.getTime() - 3600 * 1000 * 24 * 90);
                picker.$emit('pick', [start, end]);
              }
            }]
          },
            //总计
            total:{itemcode:"总计",boxnum:0},
            tableFoot:[]
        }
    },
    created() {
        this.initValidTime()
        this.getProductList()
        this.getSafetySuperVisionList()
        this.getProvince()
    },
    watch: {
    },
   computed:{
     tableData(){
       const tbody = this.productPurchaseData;
       return tbody.length ? [...tbody, ...this.tableFoot] : []
     }
   },
    methods:{
        async getProductList(){
            this.listLoading = true
            if( this.validTime !== null ){
                this.listQuery.filter.starttime = this.validTime[0]
                this.listQuery.filter.endtime = this.validTime[1]
            }else{
                this.listQuery.filter.starttime = ''
                this.listQuery.filter.endtime = ''
            }
            let res = await getProductListData(this.listQuery)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.totalCount
                this.pageSize = res.data.result.pageSize
                this.pageTotal = computePageCount(res.data.result.totalCount, res.data.result.pageSize)
                this.currentPage = res.data.result.pageIndex
                this.productPurchaseData = res.data.result.result
                this.total.boxnum = res.data.result.extension.sales
                this.tableFoot = [this.total]

            }else{
                this.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
            this.listLoading = false
        },

        async exportToExcel(){
            let res = await exportProduct(this.listQuery)
            if(res.data.code === '200'){
                if(res.data.result === null ||res.data.result === [] || res.data.result.length === 0){
                    this.$message({
                        type:'warning',
                        message:'无数据可导出'
                    })
                }else{
                    let allData = res.data.result
                    import('@/vendor/Export2Excel').then((excel) => {
                        const tHeader = [
                            '产品流向码',
                            '产品名称',
                            '箱数',
                            '每箱数量',
                            '销售数量',
                            '销售时间',
                        ]
                        const filterVal = [
                            'itemcode',
                            'itemname',
                            'boxnum',
                            'boxnumber',
                            'salenum',
                            'saletime',
                        ]
                        const data = this.formatJson(filterVal, allData)
                        excel.export_json_to_excel({
                            header: tHeader,
                            data,
                            filename: '销售汇总统计'
                        })
                    })
                }

            }else{
                this.$message({
                    message:res.data.message,
                    type:'warning'
                })
            }
        },

        formatJson(filterVal, jsonData) {
            return jsonData.map(v => filterVal.map(j => v[j]))
        },

        async getSafetySuperVisionList(){
            const params = {}
            params['dictionaryType'] = '安全监管分类'
            let res = await dictionaryAllItems(params)
            this.safetySuperVisionList = res.data.result
        },//获取安全监管分类

        async getProvince(){
            let res = await getProvinceListData()
            if(res.data.code === "200"){
                this.provinceList = res.data.result.provinceList
            }
        },//获取省

        async changeArea(value){
            if(value === 'province'){
                this.listQuery.filter.city = ''
                this.listQuery.filter.district = ''
                this.listQuery.filter.street = ''
                this.listQuery.filter.committee = ''
                this.areaListQuery = {
                    type: 2,
                    parenttype: 1,
                    parentname: this.listQuery.filter.province,
                }
                let res = await getCityListData(this.areaListQuery)
                if(res.data.code === "200"){
                    this.cityList = res.data.result
                }
            }else if(value === 'city'){
                this.listQuery.filter.district = ''
                this.listQuery.filter.street = ''
                this.listQuery.filter.committee = ''
                this.areaListQuery = {
                    type: 3,
                    parenttype: 2,
                    parentname: this.listQuery.filter.city,
                }
                let res = await getCityListData(this.areaListQuery)
                if(res.data.code === "200"){
                    this.districtList = res.data.result
                }
            }else if(value === 'district'){
                this.listQuery.filter.street = ''
                this.listQuery.filter.committee = ''
                this.areaListQuery = {
                    type: 4,
                    parenttype: 3,
                    parentname: this.listQuery.filter.district,
                }
                let res = await getCityListData(this.areaListQuery)
                if(res.data.code === "200"){
                    this.streetList = res.data.result
                }
            }else if(value === 'street'){
                this.listQuery.filter.committee = ''
                this.areaListQuery = {
                    type: 5,
                    parenttype: 4,
                    parentname: this.listQuery.filter.street,
                }
                let res = await getCityListData(this.areaListQuery)
                if(res.data.code === "200"){
                    this.committeeList = res.data.result
                }
            }
        },//市、镇、街道、委员会

        reset(){
            this.listQuery= {
                pageSize: 10,
                pageIndex: 1,
                filter: {
                    province: '',
                    city: '',
                    district: '',
                    street: '',
                    committee: '',
                    starttime: '',
                    endtime: '',
                    safetysupervision: '',
                    enterprisename: '',
                    parententerprisename: '',
                    itemname: '',
                    itemcode: '',
                },
            }
        },

        searchProductSearch(){
            this.getProductList()
        },

        handleSizeChange(val) {
            this.listQuery.pageSize = val
            this.getProductList()
        },
        handleCurrentChange(val) {
            this.listQuery.pageIndex = val
            this.getProductList()
        },
      initValidTime(){
        const start = new Date();
        const end = new Date();
        start.setTime(end.getTime() - 3600 * 1000 * 24 * 0);
        this.validTime[0] = [start.getFullYear(), start.getMonth() + 1, start.getDate()].join("-") + " 00:00:00" ;
        this.validTime[1] = [end.getFullYear(), end.getMonth() + 1, end.getDate()].join("-") +" 23:59:59";
      }
    },
}
</script>

<style scoped>
.basic_search{
    display:inline-block;
}

</style>
